searchNodes=[{"ref":"RaftFleet.html","title":"RaftFleet","type":"module","doc":"Public interface functions of raft_fleet. See also RaftFleet.Config for available application configs."},{"ref":"RaftFleet.html#activate/1","title":"RaftFleet.activate/1","type":"function","doc":"Activates Node.self(). When :raft_fleet is started as an OTP application, the node is not active; to host consensus group members each node must be explicitly activated. zone is an ID of data center zone which this node belongs to. zone is used to determine which nodes to replicate data: RaftFleet tries to place members of each consensus group across multiple zones for maximum availability. Node activation by calling this function should be done after the node is fully connected to the other existing nodes; otherwise there is a possibility that the current node, without noticing other active nodes in the cluster, initiates a new 1-member cluster instead of joining the already initiated cluster."},{"ref":"RaftFleet.html#active_nodes/0","title":"RaftFleet.active_nodes/0","type":"function","doc":"Queries the current nodes which have been activated using activate/1 in the cluster. This function sends a query to a leader of the RaftFleet.Cluster consensus group, which is managed internally by raft_fleet. The returned value is grouped by zone IDs which have been passed to activate/1. This function exits if no active node exists in the cluster."},{"ref":"RaftFleet.html#add_consensus_group/1","title":"RaftFleet.add_consensus_group/1","type":"function","doc":"Registers a new consensus group identified by name. This is a simplified version of add_consensus_group/3, where n_replica is filled with 3 (fixed value) and rv_config is computed using the module given as :rafted_value_config_maker option (see also RaftFleet.Config)."},{"ref":"RaftFleet.html#add_consensus_group/4","title":"RaftFleet.add_consensus_group/4","type":"function","doc":"Registers a new consensus group identified by name. name is used as the registered name for member processes of the new consensus group. n_replica is the number of replicas (Raft member processes implemented as RaftedValue.Server). If you want all active nodes to host member processes, specify sufficiently large integer as n_replica. For explanation of rv_config see RaftedValue.make_config/2. If you configure raft_fleet to persist Raft logs &amp; snapshots (see also RaftFleet.Config) and the consensus group with name had been removed by remove_consensus_group/1, then add_consensus_group/3 will restore the state of the consensus group from the snapshot and log files. The caller is blocked until the newly spawned leader becomes ready. await_timeout specifies how many milliseconds to wait for the initialization."},{"ref":"RaftFleet.html#command/6","title":"RaftFleet.command/6","type":"function","doc":"Executes a command on the replicated value identified by name. The target consensus group identified by name must be registered beforehand using add_consensus_group/3. This function automatically resolves the leader process of the consensus group, caches PID of the current leader in local ETS table and send the given command to the leader. timeout is used in each synchronous messaging. In order to tolerate temporal absences of leaders during Raft leader elections, it retries requests up to retry. Before retrying requests this function sleeps for retry_interval milliseconds. Thus for worst case this function blocks the caller for timeout * (retry + 1) + retry_interval * retry. Note that for complete masking of leader elections retry_interval * retry must be sufficiently longer than the time scale for leader elections (:election_timeout in RaftedValue.Config.t). call_module can be changed from the default (:gen_statem module) with an alternative module that exports call/3 for optimization of remote message passing. See also RaftedValue.command/5."},{"ref":"RaftFleet.html#consensus_groups/0","title":"RaftFleet.consensus_groups/0","type":"function","doc":"Queries already registered consensus groups. This function sends a query to a leader of the RaftFleet.Cluster consensus group, which is managed internally by raft_fleet. The returned value is a map whose keys and values are consensus group name and number of replicas of the group. This function exits if no active node exists in the cluster."},{"ref":"RaftFleet.html#deactivate/0","title":"RaftFleet.deactivate/0","type":"function","doc":"Deactivates Node.self(). Call this function before you remove an ErlangVM from your cluster. Note that calling this function does not immediately remove consensus member processes in this node; these processes will be gradually migrated to other nodes by periodic rebalancing."},{"ref":"RaftFleet.html#find_consensus_group_with_no_established_leader/0","title":"RaftFleet.find_consensus_group_with_no_established_leader/0","type":"function","doc":"Inspects members of consensus groups and finds a group (if any) in which no leader exists. If one found, returns the name of the consensus group and also statuses (as maps) of existing members. If no consensus group is in trouble, returns :ok. Target consensus groups are: RaftFleet.Cluster, which is a special consensus group that manages metadata for other consensus groups all registered consensus groups (i.e., the ones returned by RaftFleet.consensus_groups/0) This function is primarily intended to be used within remote console. Use this function to detect problematic consensus group in your cluster."},{"ref":"RaftFleet.html#query/6","title":"RaftFleet.query/6","type":"function","doc":"Executes a read-only query on the replicated value identified by name. See command/6 for explanations of name, timeout, retry, retry_interval and call_module. See also RaftedValue.query/4."},{"ref":"RaftFleet.html#remove_consensus_group/1","title":"RaftFleet.remove_consensus_group/1","type":"function","doc":"Removes an existing consensus group identified by name. Removing a consensus group will eventually trigger terminations of all members of the group. The replicated value held by the group will be discarded. Note that remove_consensus_group/1 does not immediately terminate existing member processes; they will be terminated afterward by background worker process (see also :balancing_interval in RaftFleet.Config). Note also that, if Raft logs and snapshots has been created (see also RaftFleet.Config), remove_consensus_group/1 does not remove these files."},{"ref":"RaftFleet.html#remove_dead_pids_located_in_dead_node/1","title":"RaftFleet.remove_dead_pids_located_in_dead_node/1","type":"function","doc":"Removes member pids that reside in the specified dead node from all existing consensus groups. Target consensus groups are: RaftFleet.Cluster, which is a special consensus group that manages metadata for other consensus groups all registered consensus groups (i.e., the ones returned by RaftFleet.consensus_groups/0) If a target consensus group does not have an established leader, then this function tries to remove dead pids (if any) by using RaftedValue.force_remove_member/2. This function crashes if the RaftFleet.Cluster consensus group does not have a leader. Each of the effects of this function is idempotent; you can freely call this function multiple times in case of failure. Use this function to resolve issues when e.g. some node suddenly died without cleaning up itself. The caller must be sure that the dead_node has definitely died."},{"ref":"RaftFleet.html#unreachable_nodes/0","title":"RaftFleet.unreachable_nodes/0","type":"function","doc":"Gets information about nodes that are active but unreachable from Node.self(). RaftFleet periodically checks reachability to the other active nodes. This function retrieves results of the checks as a map. Each key of the returned map is a currently unreachable node (i.e. if there&#39;s no problem %{} is returned), whereas each value is a timestamp (seconds since epoch) at which the node was recognized as unreachable. Note that returned timestamps are not so accurate about when the node failed, since they are obtained by healthchecks with an interval of :node_purge_reconnect_interval (see also RaftFleet.Config). Note also that, when a node remains unreachable for more than :node_purge_failure_time_window, the node will be automatically purged from the active nodes. After purging the failed node will not be included in return value of this function (as the node is no longer active)."},{"ref":"RaftFleet.html#whereis_leader/1","title":"RaftFleet.whereis_leader/1","type":"function","doc":"Tries to find the current leader of the consensus group specified by name. Usually you don&#39;t have to use this function as command/5 and query/5 automatically resolves where the leader resides. This function is useful when you want to inspect status of a consensus group by using e.g. RaftedValue.status/1."},{"ref":"RaftFleet.Activator.html","title":"RaftFleet.Activator","type":"module","doc":""},{"ref":"RaftFleet.Activator.html#activate/1","title":"RaftFleet.Activator.activate/1","type":"function","doc":""},{"ref":"RaftFleet.Cluster.html","title":"RaftFleet.Cluster","type":"module","doc":""},{"ref":"RaftFleet.Cluster.html#default_rv_config/0","title":"RaftFleet.Cluster.default_rv_config/0","type":"function","doc":""},{"ref":"RaftFleet.Cluster.html#make_rv_config/1","title":"RaftFleet.Cluster.make_rv_config/1","type":"function","doc":""},{"ref":"RaftFleet.Cluster.Hook.html","title":"RaftFleet.Cluster.Hook","type":"module","doc":""},{"ref":"RaftFleet.Cluster.Server.html","title":"RaftFleet.Cluster.Server","type":"module","doc":""},{"ref":"RaftFleet.Cluster.Server.html#child_spec/0","title":"RaftFleet.Cluster.Server.child_spec/0","type":"function","doc":""},{"ref":"RaftFleet.Cluster.Server.html#start_link/2","title":"RaftFleet.Cluster.Server.start_link/2","type":"function","doc":""},{"ref":"RaftFleet.Cluster.State.html","title":"RaftFleet.Cluster.State","type":"module","doc":""},{"ref":"RaftFleet.Cluster.State.html#add_group/3","title":"RaftFleet.Cluster.State.add_group/3","type":"function","doc":""},{"ref":"RaftFleet.Cluster.State.html#add_node/3","title":"RaftFleet.Cluster.State.add_node/3","type":"function","doc":""},{"ref":"RaftFleet.Cluster.State.html#consensus_groups/1","title":"RaftFleet.Cluster.State.consensus_groups/1","type":"function","doc":"Type-aware getter for consensus_groups."},{"ref":"RaftFleet.Cluster.State.html#consensus_groups/2","title":"RaftFleet.Cluster.State.consensus_groups/2","type":"function","doc":"Type-aware setter for consensus_groups."},{"ref":"RaftFleet.Cluster.State.html#members_per_leader_node/1","title":"RaftFleet.Cluster.State.members_per_leader_node/1","type":"function","doc":"Type-aware getter for members_per_leader_node."},{"ref":"RaftFleet.Cluster.State.html#members_per_leader_node/2","title":"RaftFleet.Cluster.State.members_per_leader_node/2","type":"function","doc":"Type-aware setter for members_per_leader_node."},{"ref":"RaftFleet.Cluster.State.html#new/1","title":"RaftFleet.Cluster.State.new/1","type":"function","doc":"Creates a new instance of RaftFleet.Cluster.State by using the given dict. For missing fields, default/0 of each field type will be used. Returns {:ok, valid_struct} or {:error, reason}. The values in the dict are validated by each field&#39;s valid?/1 function."},{"ref":"RaftFleet.Cluster.State.html#new!/1","title":"RaftFleet.Cluster.State.new!/1","type":"function","doc":"A variant of new/1 which returns t or raise if validation fails. In other words, new/1 followed by Croma.Result.get!/1."},{"ref":"RaftFleet.Cluster.State.html#nodes_per_zone/1","title":"RaftFleet.Cluster.State.nodes_per_zone/1","type":"function","doc":"Type-aware getter for nodes_per_zone."},{"ref":"RaftFleet.Cluster.State.html#nodes_per_zone/2","title":"RaftFleet.Cluster.State.nodes_per_zone/2","type":"function","doc":"Type-aware setter for nodes_per_zone."},{"ref":"RaftFleet.Cluster.State.html#recently_removed_groups/1","title":"RaftFleet.Cluster.State.recently_removed_groups/1","type":"function","doc":"Type-aware getter for recently_removed_groups."},{"ref":"RaftFleet.Cluster.State.html#recently_removed_groups/2","title":"RaftFleet.Cluster.State.recently_removed_groups/2","type":"function","doc":"Type-aware setter for recently_removed_groups."},{"ref":"RaftFleet.Cluster.State.html#remove_group/2","title":"RaftFleet.Cluster.State.remove_group/2","type":"function","doc":""},{"ref":"RaftFleet.Cluster.State.html#remove_node/2","title":"RaftFleet.Cluster.State.remove_node/2","type":"function","doc":""},{"ref":"RaftFleet.Cluster.State.html#update/2","title":"RaftFleet.Cluster.State.update/2","type":"function","doc":"Updates an existing instance of RaftFleet.Cluster.State with the given dict. The values in the dict are validated by each field&#39;s valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}."},{"ref":"RaftFleet.Cluster.State.html#update!/2","title":"RaftFleet.Cluster.State.update!/2","type":"function","doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1."},{"ref":"RaftFleet.Cluster.State.html#update_removed_groups/5","title":"RaftFleet.Cluster.State.update_removed_groups/5","type":"function","doc":""},{"ref":"RaftFleet.Cluster.State.html#valid?/1","title":"RaftFleet.Cluster.State.valid?/1","type":"function","doc":"Checks if the given value belongs to t/0 or not."},{"ref":"RaftFleet.Cluster.State.html#t:t/0","title":"RaftFleet.Cluster.State.t/0","type":"type","doc":""},{"ref":"RaftFleet.Config.html","title":"RaftFleet.Config","type":"module","doc":"RaftFleet defines the following application configs: :balancing_interval Time interval between periodic triggers of workers whose job is to re-balance Raft member processes across the cluster. The actual value used is obtained by Application.get_env(:raft_fleet, :balancing_interval, 60000), i.e. it defaults to 1 minute. :leader_pid_cache_refresh_interval Interval time in milliseconds of leader pids cached in each nodes&#39; local ETS tables. The actual value used is obtained by Application.get_env(:raft_fleet, :leader_pid_cache_refresh_interval, 300000), i.e. it defaults to 5 minutes. :follower_addition_delay Time duration in milliseconds to wait for before spawning a new follower for a consensus group. Concurrently spawning multiple followers may lead to race conditions (adding a member can only be done one-by-one). Although this race condition can be automatically resolved by retries and thus is basically harmless, this configuration item may be useful to reduce useless error logs. The actual value used is obtained by Application.get_env(:raft_fleet, :follower_addition_delay, 200). :node_purge_failure_time_window A node is considered &quot;unhealthy&quot; if it has been disconnected from the other nodes without declaring itself as inactive (by calling RaftFleet.deactivate/0). RaftFleet tries to reconnect to unhealthy nodes in order to recover from short-term issues such as temporary network failures (see also :node_purge_reconnect_interval below). To handle longer-term issues, RaftFleet automatically removes nodes that remain &quot;unhealthy&quot; for this time window (in milliseconds) from the list of participating active nodes. After removal, consensus member processes are automatically re-balanced within remaining active nodes. The actual value used is obtained by Application.get_env(:raft_fleet, :node_purge_failure_time_window, 600000), i.e. it defaults to 10 minutes. :node_purge_reconnect_interval Time interval (in milliseconds) of periodic reconnect attempts to disconnected nodes. The actual value used is obtained by Application.get_env(:raft_fleet, :node_purge_reconnect_interval, 60000), i.e. it defaults to 1 minute. :rafted_value_config_maker A module that implements RaftFleet.RaftedValueConfigMaker behaviour. The module is used when :raft_fleet needs to construct a RaftedValue.Config.t/0. To be more precise, it&#39;s used in RaftFleet.add_consensus_group/1, or when restoring RaftFleet.Cluster and the other consensus groups from log &amp; snapshot files. We recommend that you specify your own callback module as :rafted_value_config_maker, since, if omitted, you have the following limitations: RaftFleet.add_consensus_group/1 cannot be used (you must use RaftFleet.add_consensus_group/3 instead), and when restoring from log &amp; snapshot files, some consensus groups may not be restored (this limitation comes from the current implementation, but we don&#39;t have plan to fix this issue). Note that you can customize the RaftedValue.Config.t/0 used by the RaftFleet.Cluster consensus group. You can use RaftFleet.Cluster.make_rv_config/1 in your callback implementation. Note also that libraries using :raft_fleet may add their own consensus groups (just as in the same way as RaftFleet.Cluster expained above). Implementations of RaftFleet.RaftedValueConfigMaker behaviour must be aware of such consensus groups and return appropriate configuration when RaftFleet.RaftedValueConfigMaker.make/1 is called. :per_member_options_maker A module that implements RaftFleet.PerMemberOptionsMaker behaviour. The module is used when constructing a 2nd argument of RaftedValue.start_link/2, i.e., when starting a new consensus member process. This configuration provides a way to customize options (such as whether to persist Raft logs &amp; snapshots) for each consensus group member. Defaults to nil, which means that the default options of RaftedValue.start_link/2 are used for all consensus groups. Note that RaftFleet.Cluster (a special consensus group to manage metadata for :raft_fleet) also uses :per_member_options_maker module (if set). Callback implementation must handle RaftFleet.Cluster appropriately, in addition to consensus group names that are explicitly added by RaftFleet.add_consensus_group/3. Note also that you cannot specify :name option by your callback implementation as it&#39;s fixed by :raft_fleet. Note that each raft_fleet process uses application configs stored in the local node. If you want to configure the options above you must set them on all nodes in your cluster."},{"ref":"RaftFleet.Config.html#balancing_interval/0","title":"RaftFleet.Config.balancing_interval/0","type":"function","doc":""},{"ref":"RaftFleet.Config.html#follower_addition_delay/0","title":"RaftFleet.Config.follower_addition_delay/0","type":"function","doc":""},{"ref":"RaftFleet.Config.html#leader_pid_cache_refresh_interval/0","title":"RaftFleet.Config.leader_pid_cache_refresh_interval/0","type":"function","doc":""},{"ref":"RaftFleet.Config.html#node_purge_failure_time_window/0","title":"RaftFleet.Config.node_purge_failure_time_window/0","type":"function","doc":""},{"ref":"RaftFleet.Config.html#node_purge_reconnect_interval/0","title":"RaftFleet.Config.node_purge_reconnect_interval/0","type":"function","doc":""},{"ref":"RaftFleet.Config.html#per_member_options_maker/0","title":"RaftFleet.Config.per_member_options_maker/0","type":"function","doc":""},{"ref":"RaftFleet.Config.html#rafted_value_config_maker/0","title":"RaftFleet.Config.rafted_value_config_maker/0","type":"function","doc":""},{"ref":"RaftFleet.ConsensusGroups.html","title":"RaftFleet.ConsensusGroups","type":"module","doc":""},{"ref":"RaftFleet.ConsensusGroups.html#valid?/1","title":"RaftFleet.ConsensusGroups.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.ConsensusGroups.html#t:t/0","title":"RaftFleet.ConsensusGroups.t/0","type":"type","doc":""},{"ref":"RaftFleet.ConsensusMemberAdjuster.html","title":"RaftFleet.ConsensusMemberAdjuster","type":"module","doc":""},{"ref":"RaftFleet.ConsensusMemberAdjuster.html#adjust/0","title":"RaftFleet.ConsensusMemberAdjuster.adjust/0","type":"function","doc":""},{"ref":"RaftFleet.ConsensusMemberSup.html","title":"RaftFleet.ConsensusMemberSup","type":"module","doc":""},{"ref":"RaftFleet.ConsensusMemberSup.html#child_spec/1","title":"RaftFleet.ConsensusMemberSup.child_spec/1","type":"function","doc":""},{"ref":"RaftFleet.ConsensusMemberSup.html#start_link/0","title":"RaftFleet.ConsensusMemberSup.start_link/0","type":"function","doc":""},{"ref":"RaftFleet.ConsensusMemberSup.RaftedValueWrapper.html","title":"RaftFleet.ConsensusMemberSup.RaftedValueWrapper","type":"module","doc":""},{"ref":"RaftFleet.ConsensusMemberSup.RaftedValueWrapper.html#start_link/2","title":"RaftFleet.ConsensusMemberSup.RaftedValueWrapper.start_link/2","type":"function","doc":""},{"ref":"RaftFleet.ConsensusNodesPair.html","title":"RaftFleet.ConsensusNodesPair","type":"module","doc":""},{"ref":"RaftFleet.ConsensusNodesPair.html#valid?/1","title":"RaftFleet.ConsensusNodesPair.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.ConsensusNodesPair.html#t:t/0","title":"RaftFleet.ConsensusNodesPair.t/0","type":"type","doc":""},{"ref":"RaftFleet.Deactivator.html","title":"RaftFleet.Deactivator","type":"module","doc":""},{"ref":"RaftFleet.Deactivator.html#deactivate/0","title":"RaftFleet.Deactivator.deactivate/0","type":"function","doc":""},{"ref":"RaftFleet.Hash.html","title":"RaftFleet.Hash","type":"module","doc":""},{"ref":"RaftFleet.Hash.html#calc/1","title":"RaftFleet.Hash.calc/1","type":"function","doc":""},{"ref":"RaftFleet.Hash.html#max/0","title":"RaftFleet.Hash.max/0","type":"function","doc":""},{"ref":"RaftFleet.Hash.html#min/0","title":"RaftFleet.Hash.min/0","type":"function","doc":""},{"ref":"RaftFleet.Hash.html#valid?/1","title":"RaftFleet.Hash.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.Hash.html#t:t/0","title":"RaftFleet.Hash.t/0","type":"type","doc":""},{"ref":"RaftFleet.LeaderPidCache.html","title":"RaftFleet.LeaderPidCache","type":"module","doc":""},{"ref":"RaftFleet.LeaderPidCache.html#get/1","title":"RaftFleet.LeaderPidCache.get/1","type":"function","doc":""},{"ref":"RaftFleet.LeaderPidCache.html#init/0","title":"RaftFleet.LeaderPidCache.init/0","type":"function","doc":""},{"ref":"RaftFleet.LeaderPidCache.html#keys/0","title":"RaftFleet.LeaderPidCache.keys/0","type":"function","doc":""},{"ref":"RaftFleet.LeaderPidCache.html#set/2","title":"RaftFleet.LeaderPidCache.set/2","type":"function","doc":""},{"ref":"RaftFleet.LeaderPidCache.html#unset/1","title":"RaftFleet.LeaderPidCache.unset/1","type":"function","doc":""},{"ref":"RaftFleet.LeaderPidCacheRefresher.html","title":"RaftFleet.LeaderPidCacheRefresher","type":"module","doc":"A GenServer that periodically fetches all locally-stored leader pid caches and refreshes stale ones."},{"ref":"RaftFleet.LeaderPidCacheRefresher.html#child_spec/1","title":"RaftFleet.LeaderPidCacheRefresher.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"RaftFleet.LeaderPidCacheRefresher.html#init/1","title":"RaftFleet.LeaderPidCacheRefresher.init/1","type":"function","doc":"Invoked when the server is started. start_link/3 or start/3 will block until it returns. init_arg is the argument term (second argument) passed to start_link/3. Returning {:ok, state} will cause start_link/3 to return {:ok, pid} and the process to enter its loop. Returning {:ok, state, timeout} is similar to {:ok, state}, except that it also sets a timeout. See the &quot;Timeouts&quot; section in the module documentation for more information. Returning {:ok, state, :hibernate} is similar to {:ok, state} except the process is hibernated before entering the loop. See c:handle_call/3 for more information on hibernation. Returning {:ok, state, {:continue, continue}} is similar to {:ok, state} except that immediately after entering the loop the c:handle_continue/2 callback will be invoked with the value continue as first argument. Returning :ignore will cause start_link/3 to return :ignore and the process will exit normally without entering the loop or calling c:terminate/2. If used when part of a supervision tree the parent supervisor will not fail to start nor immediately try to restart the GenServer. The remainder of the supervision tree will be started and so the GenServer should not be required by other processes. It can be started later with Supervisor.restart_child/2 as the child specification is saved in the parent supervisor. The main use cases for this are: The GenServer is disabled by configuration but might be enabled later. An error occurred and it will be handled by a different mechanism than the Supervisor. Likely this approach involves calling Supervisor.restart_child/2 after a delay to attempt a restart. Returning {:stop, reason} will cause start_link/3 to return {:error, reason} and the process to exit with reason reason without entering the loop or calling c:terminate/2. Callback implementation for GenServer.init/1."},{"ref":"RaftFleet.LeaderPidCacheRefresher.html#start_link/1","title":"RaftFleet.LeaderPidCacheRefresher.start_link/1","type":"function","doc":""},{"ref":"RaftFleet.Manager.html","title":"RaftFleet.Manager","type":"module","doc":""},{"ref":"RaftFleet.Manager.html#child_spec/1","title":"RaftFleet.Manager.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"RaftFleet.Manager.html#init/1","title":"RaftFleet.Manager.init/1","type":"function","doc":"Invoked when the server is started. start_link/3 or start/3 will block until it returns. init_arg is the argument term (second argument) passed to start_link/3. Returning {:ok, state} will cause start_link/3 to return {:ok, pid} and the process to enter its loop. Returning {:ok, state, timeout} is similar to {:ok, state}, except that it also sets a timeout. See the &quot;Timeouts&quot; section in the module documentation for more information. Returning {:ok, state, :hibernate} is similar to {:ok, state} except the process is hibernated before entering the loop. See c:handle_call/3 for more information on hibernation. Returning {:ok, state, {:continue, continue}} is similar to {:ok, state} except that immediately after entering the loop the c:handle_continue/2 callback will be invoked with the value continue as first argument. Returning :ignore will cause start_link/3 to return :ignore and the process will exit normally without entering the loop or calling c:terminate/2. If used when part of a supervision tree the parent supervisor will not fail to start nor immediately try to restart the GenServer. The remainder of the supervision tree will be started and so the GenServer should not be required by other processes. It can be started later with Supervisor.restart_child/2 as the child specification is saved in the parent supervisor. The main use cases for this are: The GenServer is disabled by configuration but might be enabled later. An error occurred and it will be handled by a different mechanism than the Supervisor. Likely this approach involves calling Supervisor.restart_child/2 after a delay to attempt a restart. Returning {:stop, reason} will cause start_link/3 to return {:error, reason} and the process to exit with reason reason without entering the loop or calling c:terminate/2. Callback implementation for GenServer.init/1."},{"ref":"RaftFleet.Manager.html#start_consensus_group_follower/4","title":"RaftFleet.Manager.start_consensus_group_follower/4","type":"function","doc":""},{"ref":"RaftFleet.Manager.html#start_consensus_group_members/4","title":"RaftFleet.Manager.start_consensus_group_members/4","type":"function","doc":""},{"ref":"RaftFleet.Manager.html#start_link/1","title":"RaftFleet.Manager.start_link/1","type":"function","doc":""},{"ref":"RaftFleet.Manager.State.html","title":"RaftFleet.Manager.State","type":"module","doc":""},{"ref":"RaftFleet.Manager.State.html#activate_worker/1","title":"RaftFleet.Manager.State.activate_worker/1","type":"function","doc":"Type-aware getter for activate_worker."},{"ref":"RaftFleet.Manager.State.html#activate_worker/2","title":"RaftFleet.Manager.State.activate_worker/2","type":"function","doc":"Type-aware setter for activate_worker."},{"ref":"RaftFleet.Manager.State.html#adjust_timer/1","title":"RaftFleet.Manager.State.adjust_timer/1","type":"function","doc":"Type-aware getter for adjust_timer."},{"ref":"RaftFleet.Manager.State.html#adjust_timer/2","title":"RaftFleet.Manager.State.adjust_timer/2","type":"function","doc":"Type-aware setter for adjust_timer."},{"ref":"RaftFleet.Manager.State.html#adjust_worker/1","title":"RaftFleet.Manager.State.adjust_worker/1","type":"function","doc":"Type-aware getter for adjust_worker."},{"ref":"RaftFleet.Manager.State.html#adjust_worker/2","title":"RaftFleet.Manager.State.adjust_worker/2","type":"function","doc":"Type-aware setter for adjust_worker."},{"ref":"RaftFleet.Manager.State.html#being_added_consensus_groups/1","title":"RaftFleet.Manager.State.being_added_consensus_groups/1","type":"function","doc":"Type-aware getter for being_added_consensus_groups."},{"ref":"RaftFleet.Manager.State.html#being_added_consensus_groups/2","title":"RaftFleet.Manager.State.being_added_consensus_groups/2","type":"function","doc":"Type-aware setter for being_added_consensus_groups."},{"ref":"RaftFleet.Manager.State.html#deactivate_worker/1","title":"RaftFleet.Manager.State.deactivate_worker/1","type":"function","doc":"Type-aware getter for deactivate_worker."},{"ref":"RaftFleet.Manager.State.html#deactivate_worker/2","title":"RaftFleet.Manager.State.deactivate_worker/2","type":"function","doc":"Type-aware setter for deactivate_worker."},{"ref":"RaftFleet.Manager.State.html#new/1","title":"RaftFleet.Manager.State.new/1","type":"function","doc":"Creates a new instance of RaftFleet.Manager.State by using the given dict. For missing fields, default/0 of each field type will be used. Returns {:ok, valid_struct} or {:error, reason}. The values in the dict are validated by each field&#39;s valid?/1 function."},{"ref":"RaftFleet.Manager.State.html#new!/1","title":"RaftFleet.Manager.State.new!/1","type":"function","doc":"A variant of new/1 which returns t or raise if validation fails. In other words, new/1 followed by Croma.Result.get!/1."},{"ref":"RaftFleet.Manager.State.html#phase/1","title":"RaftFleet.Manager.State.phase/1","type":"function","doc":""},{"ref":"RaftFleet.Manager.State.html#update/2","title":"RaftFleet.Manager.State.update/2","type":"function","doc":"Updates an existing instance of RaftFleet.Manager.State with the given dict. The values in the dict are validated by each field&#39;s valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}."},{"ref":"RaftFleet.Manager.State.html#update!/2","title":"RaftFleet.Manager.State.update!/2","type":"function","doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1."},{"ref":"RaftFleet.Manager.State.html#update_being_added_consensus_groups/3","title":"RaftFleet.Manager.State.update_being_added_consensus_groups/3","type":"function","doc":""},{"ref":"RaftFleet.Manager.State.html#valid?/1","title":"RaftFleet.Manager.State.valid?/1","type":"function","doc":"Checks if the given value belongs to t/0 or not."},{"ref":"RaftFleet.Manager.State.html#t:consensus_group_progress/0","title":"RaftFleet.Manager.State.consensus_group_progress/0","type":"type","doc":""},{"ref":"RaftFleet.Manager.State.html#t:t/0","title":"RaftFleet.Manager.State.t/0","type":"type","doc":""},{"ref":"RaftFleet.MembersPerLeaderNode.html","title":"RaftFleet.MembersPerLeaderNode","type":"module","doc":""},{"ref":"RaftFleet.MembersPerLeaderNode.html#valid?/1","title":"RaftFleet.MembersPerLeaderNode.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.MembersPerLeaderNode.html#t:t/0","title":"RaftFleet.MembersPerLeaderNode.t/0","type":"type","doc":""},{"ref":"RaftFleet.NodeReconnector.html","title":"RaftFleet.NodeReconnector","type":"module","doc":""},{"ref":"RaftFleet.NodeReconnector.html#child_spec/1","title":"RaftFleet.NodeReconnector.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"RaftFleet.NodeReconnector.html#init/1","title":"RaftFleet.NodeReconnector.init/1","type":"function","doc":"Invoked when the server is started. start_link/3 or start/3 will block until it returns. init_arg is the argument term (second argument) passed to start_link/3. Returning {:ok, state} will cause start_link/3 to return {:ok, pid} and the process to enter its loop. Returning {:ok, state, timeout} is similar to {:ok, state}, except that it also sets a timeout. See the &quot;Timeouts&quot; section in the module documentation for more information. Returning {:ok, state, :hibernate} is similar to {:ok, state} except the process is hibernated before entering the loop. See c:handle_call/3 for more information on hibernation. Returning {:ok, state, {:continue, continue}} is similar to {:ok, state} except that immediately after entering the loop the c:handle_continue/2 callback will be invoked with the value continue as first argument. Returning :ignore will cause start_link/3 to return :ignore and the process will exit normally without entering the loop or calling c:terminate/2. If used when part of a supervision tree the parent supervisor will not fail to start nor immediately try to restart the GenServer. The remainder of the supervision tree will be started and so the GenServer should not be required by other processes. It can be started later with Supervisor.restart_child/2 as the child specification is saved in the parent supervisor. The main use cases for this are: The GenServer is disabled by configuration but might be enabled later. An error occurred and it will be handled by a different mechanism than the Supervisor. Likely this approach involves calling Supervisor.restart_child/2 after a delay to attempt a restart. Returning {:stop, reason} will cause start_link/3 to return {:error, reason} and the process to exit with reason reason without entering the loop or calling c:terminate/2. Callback implementation for GenServer.init/1."},{"ref":"RaftFleet.NodeReconnector.html#start_link/1","title":"RaftFleet.NodeReconnector.start_link/1","type":"function","doc":""},{"ref":"RaftFleet.NodeReconnector.State.html","title":"RaftFleet.NodeReconnector.State","type":"module","doc":""},{"ref":"RaftFleet.NodeReconnector.State.html#new/1","title":"RaftFleet.NodeReconnector.State.new/1","type":"function","doc":"Creates a new instance of RaftFleet.NodeReconnector.State by using the given dict. For missing fields, default/0 of each field type will be used. Returns {:ok, valid_struct} or {:error, reason}. The values in the dict are validated by each field&#39;s valid?/1 function."},{"ref":"RaftFleet.NodeReconnector.State.html#new!/1","title":"RaftFleet.NodeReconnector.State.new!/1","type":"function","doc":"A variant of new/1 which returns t or raise if validation fails. In other words, new/1 followed by Croma.Result.get!/1."},{"ref":"RaftFleet.NodeReconnector.State.html#other_active_nodes/1","title":"RaftFleet.NodeReconnector.State.other_active_nodes/1","type":"function","doc":"Type-aware getter for other_active_nodes."},{"ref":"RaftFleet.NodeReconnector.State.html#other_active_nodes/2","title":"RaftFleet.NodeReconnector.State.other_active_nodes/2","type":"function","doc":"Type-aware setter for other_active_nodes."},{"ref":"RaftFleet.NodeReconnector.State.html#other_node_activated/2","title":"RaftFleet.NodeReconnector.State.other_node_activated/2","type":"function","doc":""},{"ref":"RaftFleet.NodeReconnector.State.html#refresh/1","title":"RaftFleet.NodeReconnector.State.refresh/1","type":"function","doc":""},{"ref":"RaftFleet.NodeReconnector.State.html#this_node_activated/1","title":"RaftFleet.NodeReconnector.State.this_node_activated/1","type":"function","doc":""},{"ref":"RaftFleet.NodeReconnector.State.html#this_node_active?/1","title":"RaftFleet.NodeReconnector.State.this_node_active?/1","type":"function","doc":"Type-aware getter for this_node_active?."},{"ref":"RaftFleet.NodeReconnector.State.html#this_node_active?/2","title":"RaftFleet.NodeReconnector.State.this_node_active?/2","type":"function","doc":"Type-aware setter for this_node_active?."},{"ref":"RaftFleet.NodeReconnector.State.html#this_node_deactivated/1","title":"RaftFleet.NodeReconnector.State.this_node_deactivated/1","type":"function","doc":""},{"ref":"RaftFleet.NodeReconnector.State.html#unhealthy_since/1","title":"RaftFleet.NodeReconnector.State.unhealthy_since/1","type":"function","doc":"Type-aware getter for unhealthy_since."},{"ref":"RaftFleet.NodeReconnector.State.html#unhealthy_since/2","title":"RaftFleet.NodeReconnector.State.unhealthy_since/2","type":"function","doc":"Type-aware setter for unhealthy_since."},{"ref":"RaftFleet.NodeReconnector.State.html#unreachable_nodes/1","title":"RaftFleet.NodeReconnector.State.unreachable_nodes/1","type":"function","doc":""},{"ref":"RaftFleet.NodeReconnector.State.html#update/2","title":"RaftFleet.NodeReconnector.State.update/2","type":"function","doc":"Updates an existing instance of RaftFleet.NodeReconnector.State with the given dict. The values in the dict are validated by each field&#39;s valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}."},{"ref":"RaftFleet.NodeReconnector.State.html#update!/2","title":"RaftFleet.NodeReconnector.State.update!/2","type":"function","doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1."},{"ref":"RaftFleet.NodeReconnector.State.html#update_active_nodes/2","title":"RaftFleet.NodeReconnector.State.update_active_nodes/2","type":"function","doc":""},{"ref":"RaftFleet.NodeReconnector.State.html#valid?/1","title":"RaftFleet.NodeReconnector.State.valid?/1","type":"function","doc":"Checks if the given value belongs to t/0 or not."},{"ref":"RaftFleet.NodeReconnector.State.html#t:t/0","title":"RaftFleet.NodeReconnector.State.t/0","type":"type","doc":""},{"ref":"RaftFleet.NodesPerZone.html","title":"RaftFleet.NodesPerZone","type":"module","doc":""},{"ref":"RaftFleet.NodesPerZone.html#lrw_members/3","title":"RaftFleet.NodesPerZone.lrw_members/3","type":"function","doc":""},{"ref":"RaftFleet.NodesPerZone.html#valid?/1","title":"RaftFleet.NodesPerZone.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.NodesPerZone.html#t:t/0","title":"RaftFleet.NodesPerZone.t/0","type":"type","doc":""},{"ref":"RaftFleet.PerMemberOptions.html","title":"RaftFleet.PerMemberOptions","type":"module","doc":""},{"ref":"RaftFleet.PerMemberOptions.html#build/1","title":"RaftFleet.PerMemberOptions.build/1","type":"function","doc":""},{"ref":"RaftFleet.PerMemberOptionsMaker.html","title":"RaftFleet.PerMemberOptionsMaker","type":"behaviour","doc":""},{"ref":"RaftFleet.PerMemberOptionsMaker.html#c:make/1","title":"RaftFleet.PerMemberOptionsMaker.make/1","type":"callback","doc":""},{"ref":"RaftFleet.ProcessAndDiskLogIndexInspector.html","title":"RaftFleet.ProcessAndDiskLogIndexInspector","type":"module","doc":"A GenServer that reports &quot;eligibility&quot; of a node for hosting the 1st member of a new consensus group. When starting a new consensus group, a manager process collects reports from all active nodes and determine where to spawn the 1st member process. The report includes: whether there exists a process whose registered name equals to the consensus group name last log index in locally stored files (if any)"},{"ref":"RaftFleet.ProcessAndDiskLogIndexInspector.html#child_spec/1","title":"RaftFleet.ProcessAndDiskLogIndexInspector.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"RaftFleet.ProcessAndDiskLogIndexInspector.html#find_node_having_latest_log_index/1","title":"RaftFleet.ProcessAndDiskLogIndexInspector.find_node_having_latest_log_index/1","type":"function","doc":""},{"ref":"RaftFleet.ProcessAndDiskLogIndexInspector.html#init/1","title":"RaftFleet.ProcessAndDiskLogIndexInspector.init/1","type":"function","doc":"Invoked when the server is started. start_link/3 or start/3 will block until it returns. init_arg is the argument term (second argument) passed to start_link/3. Returning {:ok, state} will cause start_link/3 to return {:ok, pid} and the process to enter its loop. Returning {:ok, state, timeout} is similar to {:ok, state}, except that it also sets a timeout. See the &quot;Timeouts&quot; section in the module documentation for more information. Returning {:ok, state, :hibernate} is similar to {:ok, state} except the process is hibernated before entering the loop. See c:handle_call/3 for more information on hibernation. Returning {:ok, state, {:continue, continue}} is similar to {:ok, state} except that immediately after entering the loop the c:handle_continue/2 callback will be invoked with the value continue as first argument. Returning :ignore will cause start_link/3 to return :ignore and the process will exit normally without entering the loop or calling c:terminate/2. If used when part of a supervision tree the parent supervisor will not fail to start nor immediately try to restart the GenServer. The remainder of the supervision tree will be started and so the GenServer should not be required by other processes. It can be started later with Supervisor.restart_child/2 as the child specification is saved in the parent supervisor. The main use cases for this are: The GenServer is disabled by configuration but might be enabled later. An error occurred and it will be handled by a different mechanism than the Supervisor. Likely this approach involves calling Supervisor.restart_child/2 after a delay to attempt a restart. Returning {:stop, reason} will cause start_link/3 to return {:error, reason} and the process to exit with reason reason without entering the loop or calling c:terminate/2. Callback implementation for GenServer.init/1."},{"ref":"RaftFleet.ProcessAndDiskLogIndexInspector.html#start_link/1","title":"RaftFleet.ProcessAndDiskLogIndexInspector.start_link/1","type":"function","doc":""},{"ref":"RaftFleet.RaftedValueConfigMaker.html","title":"RaftFleet.RaftedValueConfigMaker","type":"behaviour","doc":""},{"ref":"RaftFleet.RaftedValueConfigMaker.html#c:make/1","title":"RaftFleet.RaftedValueConfigMaker.make/1","type":"callback","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.html","title":"RaftFleet.RecentlyRemovedGroups","type":"module","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.html#active_nodes/1","title":"RaftFleet.RecentlyRemovedGroups.active_nodes/1","type":"function","doc":"Type-aware getter for active_nodes."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#active_nodes/2","title":"RaftFleet.RecentlyRemovedGroups.active_nodes/2","type":"function","doc":"Type-aware setter for active_nodes."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#add/2","title":"RaftFleet.RecentlyRemovedGroups.add/2","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.html#cancel/2","title":"RaftFleet.RecentlyRemovedGroups.cancel/2","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.html#cleanup_ongoing?/2","title":"RaftFleet.RecentlyRemovedGroups.cleanup_ongoing?/2","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.html#empty/0","title":"RaftFleet.RecentlyRemovedGroups.empty/0","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.html#group_to_indices/1","title":"RaftFleet.RecentlyRemovedGroups.group_to_indices/1","type":"function","doc":"Type-aware getter for group_to_indices."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#group_to_indices/2","title":"RaftFleet.RecentlyRemovedGroups.group_to_indices/2","type":"function","doc":"Type-aware setter for group_to_indices."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#index_to_group/1","title":"RaftFleet.RecentlyRemovedGroups.index_to_group/1","type":"function","doc":"Type-aware getter for index_to_group."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#index_to_group/2","title":"RaftFleet.RecentlyRemovedGroups.index_to_group/2","type":"function","doc":"Type-aware setter for index_to_group."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#max_index/1","title":"RaftFleet.RecentlyRemovedGroups.max_index/1","type":"function","doc":"Type-aware getter for max_index."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#max_index/2","title":"RaftFleet.RecentlyRemovedGroups.max_index/2","type":"function","doc":"Type-aware setter for max_index."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#min_index/1","title":"RaftFleet.RecentlyRemovedGroups.min_index/1","type":"function","doc":"Type-aware getter for min_index."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#min_index/2","title":"RaftFleet.RecentlyRemovedGroups.min_index/2","type":"function","doc":"Type-aware setter for min_index."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#names_for_node/2","title":"RaftFleet.RecentlyRemovedGroups.names_for_node/2","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.html#new/1","title":"RaftFleet.RecentlyRemovedGroups.new/1","type":"function","doc":"Creates a new instance of RaftFleet.RecentlyRemovedGroups by using the given dict. For missing fields, default/0 of each field type will be used. Returns {:ok, valid_struct} or {:error, reason}. The values in the dict are validated by each field&#39;s valid?/1 function."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#new!/1","title":"RaftFleet.RecentlyRemovedGroups.new!/1","type":"function","doc":"A variant of new/1 which returns t or raise if validation fails. In other words, new/1 followed by Croma.Result.get!/1."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#update/2","title":"RaftFleet.RecentlyRemovedGroups.update/2","type":"function","doc":"Updates an existing instance of RaftFleet.RecentlyRemovedGroups with the given dict. The values in the dict are validated by each field&#39;s valid?/1 function. Returns {:ok, valid_struct} or {:error, reason}."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#update/6","title":"RaftFleet.RecentlyRemovedGroups.update/6","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.html#update!/2","title":"RaftFleet.RecentlyRemovedGroups.update!/2","type":"function","doc":"A variant of update/2 which returns t or raise if validation fails. In other words, update/2 followed by Croma.Result.get!/1."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#valid?/1","title":"RaftFleet.RecentlyRemovedGroups.valid?/1","type":"function","doc":"Checks if the given value belongs to t/0 or not."},{"ref":"RaftFleet.RecentlyRemovedGroups.html#t:t/0","title":"RaftFleet.RecentlyRemovedGroups.t/0","type":"type","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.GroupNameToIndices.html","title":"RaftFleet.RecentlyRemovedGroups.GroupNameToIndices","type":"module","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.GroupNameToIndices.html#valid?/1","title":"RaftFleet.RecentlyRemovedGroups.GroupNameToIndices.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.GroupNameToIndices.html#t:t/0","title":"RaftFleet.RecentlyRemovedGroups.GroupNameToIndices.t/0","type":"type","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.IndexToGroupName.html","title":"RaftFleet.RecentlyRemovedGroups.IndexToGroupName","type":"module","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.IndexToGroupName.html#valid?/1","title":"RaftFleet.RecentlyRemovedGroups.IndexToGroupName.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.IndexToGroupName.html#t:t/0","title":"RaftFleet.RecentlyRemovedGroups.IndexToGroupName.t/0","type":"type","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.NodesMap.html","title":"RaftFleet.RecentlyRemovedGroups.NodesMap","type":"module","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.NodesMap.html#valid?/1","title":"RaftFleet.RecentlyRemovedGroups.NodesMap.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.NodesMap.html#t:t/0","title":"RaftFleet.RecentlyRemovedGroups.NodesMap.t/0","type":"type","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.NodesMap.Pair.html","title":"RaftFleet.RecentlyRemovedGroups.NodesMap.Pair","type":"module","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.NodesMap.Pair.html#valid?/1","title":"RaftFleet.RecentlyRemovedGroups.NodesMap.Pair.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.RecentlyRemovedGroups.NodesMap.Pair.html#t:t/0","title":"RaftFleet.RecentlyRemovedGroups.NodesMap.Pair.t/0","type":"type","doc":""},{"ref":"RaftFleet.Util.html","title":"RaftFleet.Util","type":"module","doc":""},{"ref":"RaftFleet.Util.html#find_leader_and_cache/1","title":"RaftFleet.Util.find_leader_and_cache/1","type":"function","doc":""},{"ref":"RaftFleet.Util.html#retrieve_member_statuses/1","title":"RaftFleet.Util.retrieve_member_statuses/1","type":"function","doc":""},{"ref":"RaftFleet.Util.html#try_status/1","title":"RaftFleet.Util.try_status/1","type":"function","doc":""},{"ref":"RaftFleet.ZoneId.html","title":"RaftFleet.ZoneId","type":"module","doc":""},{"ref":"RaftFleet.ZoneId.html#valid?/1","title":"RaftFleet.ZoneId.valid?/1","type":"function","doc":""},{"ref":"RaftFleet.ZoneId.html#t:t/0","title":"RaftFleet.ZoneId.t/0","type":"type","doc":""}]